# Table of Contents

- [erp-transformation-explore](<./erp-transformation-explore.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Phase 3. Explore: Define the To-Be Architecture](<./Phase-3.-Explore-Define-the-To-Be-Architecture.md>)
  - [Overview](<./Phase-3.-Explore-Define-the-To-Be-Architecture/Overview.md>)
  - [Step 1. Add Transformations and Impacts With Architecture and Road Map Planning](<./Phase-3.-Explore-Define-the-To-Be-Architecture/Step-1.-Add-Transformations-and-Impacts-With-Architecture-and-Road-Map-Planning.md>)
  - [Step 2. Evaluate Data](<./Phase-3.-Explore-Define-the-To-Be-Architecture/Step-2.-Evaluate-Data.md>)
  - [Step 3. Report and Communicate](<./Phase-3.-Explore-Define-the-To-Be-Architecture/Step-3.-Report-and-Communicate.md>)
